package dk.dionysus.hjarl;

import org.anddev.andengine.engine.Engine;
import org.anddev.andengine.engine.camera.Camera;
import org.anddev.andengine.engine.options.EngineOptions;
import org.anddev.andengine.engine.options.EngineOptions.ScreenOrientation;
import org.anddev.andengine.engine.options.resolutionpolicy.RatioResolutionPolicy;
import org.anddev.andengine.entity.IEntity;
import org.anddev.andengine.entity.modifier.AlphaModifier;
import org.anddev.andengine.entity.modifier.DelayModifier;
import org.anddev.andengine.entity.modifier.IEntityModifier.IEntityModifierListener;
import org.anddev.andengine.entity.modifier.LoopEntityModifier;
import org.anddev.andengine.entity.modifier.LoopEntityModifier.ILoopEntityModifierListener;
import org.anddev.andengine.entity.modifier.SequenceEntityModifier;
import org.anddev.andengine.entity.scene.Scene;
import org.anddev.andengine.entity.scene.background.ColorBackground;
import org.anddev.andengine.entity.sprite.Sprite;
import org.anddev.andengine.opengl.texture.TextureOptions;
import org.anddev.andengine.opengl.texture.atlas.bitmap.BitmapTextureAtlas;
import org.anddev.andengine.opengl.texture.atlas.bitmap.BitmapTextureAtlasTextureRegionFactory;
import org.anddev.andengine.opengl.texture.atlas.bitmap.source.IBitmapTextureAtlasSource;
import org.anddev.andengine.opengl.texture.region.TextureRegion;
import org.anddev.andengine.ui.activity.BaseGameActivity;
import org.anddev.andengine.ui.activity.BaseSplashActivity;
import org.anddev.andengine.util.modifier.IModifier;
import org.anddev.andengine.util.modifier.LoopModifier;

import android.app.Activity;
import android.content.Intent;
import android.view.KeyEvent;
import android.widget.Toast;

public class GameSplashActivity extends BaseGameActivity {
        private static final int CAMERA_WIDTH = 470;
        private static final int CAMERA_HEIGHT = 270;
        
        private Camera camera;
        private BitmapTextureAtlas texture;
        private TextureRegion pictureRegion;
        //private final String backgroundImage = "gfx/AndEngineText.png";
        
        @Override
        public Engine onLoadEngine() {
    		this.camera = new Camera(0, 0, CAMERA_WIDTH, CAMERA_HEIGHT);
    		final EngineOptions engineOptions = new EngineOptions(true,
    				ScreenOrientation.LANDSCAPE, new RatioResolutionPolicy(
    						CAMERA_WIDTH, CAMERA_HEIGHT), this.camera);
    		return new Engine(engineOptions);
        }

        @Override
        public void onLoadResources() {
                texture = new BitmapTextureAtlas(512, 512, TextureOptions.BILINEAR);
                BitmapTextureAtlasTextureRegionFactory.setAssetBasePath("gfx/");
                pictureRegion = BitmapTextureAtlasTextureRegionFactory.createFromAsset(this.texture, this, "startbox.png", 0, 0);
                mEngine.getTextureManager().loadTexture(this.texture);
        }

        @Override
        public Scene onLoadScene() {
                final Scene scene = new Scene(1);
                scene.setBackground(new ColorBackground(0, 0, 0));

                final int x = (CAMERA_WIDTH - this.pictureRegion.getWidth()) / 2;
                final int y = (CAMERA_HEIGHT - this.pictureRegion.getHeight()) / 2;
                

                final Sprite picture = new Sprite(x, y, this.pictureRegion);
                picture.setAlpha(0); // makes our picture sprite transparent
  
                // I took this entity modifier code from the AndEngineExamples 
        		final LoopEntityModifier entityModifier =
        			new LoopEntityModifier(
        					new IEntityModifierListener() {
        						@Override
        						public void onModifierStarted(final IModifier<IEntity> pModifier, final IEntity pItem) {
        							GameSplashActivity.this.runOnUiThread(new Runnable() {
        								@Override
        								public void run() {
        									// Any code here will run at the same time as the splash screen runs
        									
        									// Toast for debugging
        									// Toast.makeText(GameSplashActivity.this, "Sequence started.", Toast.LENGTH_SHORT).show();
        								}
        							});
        						}

        						@Override
        						public void onModifierFinished(final IModifier<IEntity> pEntityModifier, final IEntity pEntity) {
        							GameSplashActivity.this.runOnUiThread(new Runnable() {
        								@Override
        								public void run() {
        									// Any code here will run at the same time as the splash screen finishes
        									
        									// Toast for debugging
        									// Toast.makeText(GameSplashActivity.this, "Sequence finished.", Toast.LENGTH_SHORT).show();
    										Intent menu = new Intent(GameSplashActivity.this, ScrollMenu.class); // Creates an intent in this activity, to prepare the next class
    										startActivity(menu); // Runs the menu activity
    										finish(); // Ends this activity to stop it from hogging precious Android memory.
        								}
        							});
        						}
        					},
        					2, // Loop count. Want more loops to add more splash screens or something else? Just change this number. 
        					new ILoopEntityModifierListener() {
        						@Override
        						public void onLoopStarted(final LoopModifier<IEntity> pLoopModifier, final int pLoop, final int pLoopCount) {
        							GameSplashActivity.this.runOnUiThread(new Runnable() {
        								@Override
        								public void run() {
        									// Do something while the loop is rolling
        									
        									
        									
        									// A toast message that is useful for debugging.
        									//Toast.makeText(GameSplashActivity.this, "Loop: '" + (pLoop + 1) + "' of '" + pLoopCount + "' started.", Toast.LENGTH_SHORT).show();
        								}
        							});
        						}

        						@Override
        						public void onLoopFinished(final LoopModifier<IEntity> pLoopModifier, final int pLoop, final int pLoopCount) {
        							GameSplashActivity.this.runOnUiThread(new Runnable() {
        								@Override
        								public void run() {
        									// Toast.makeText(GameSplashActivity.this, "Loop: '" + (pLoop + 1) + "' of '" + pLoopCount + "' finished.", Toast.LENGTH_SHORT).show();
        									if (pLoop == 0) { //pLoop is the number of times this modifier has been loop.
        										texture.clearTextureAtlasSources(); // Clear the first splash screen from our texture
        										BitmapTextureAtlasTextureRegionFactory.createFromAsset(texture, GameSplashActivity.this, "AndEngineText.png", 0, 0); // Load the second splash screen onto the texture instead 
        									}
        									if (pLoop == 1) { //pLoop is the number of times this modifier has been loop.
        										texture.clearTextureAtlasSources(); // Clear the first splash screen from our texture
        										BitmapTextureAtlasTextureRegionFactory.createFromAsset(texture, GameSplashActivity.this, "startbox2.png", 0, 0); // Load the second splash screen onto the texture instead 
        									}
        									if (pLoop == 2) { //pLoop is the number of times this modifier has been loop.
        										texture.clearTextureAtlasSources(); // Clear the first splash screen from our texture
        										BitmapTextureAtlasTextureRegionFactory.createFromAsset(texture, GameSplashActivity.this, "startbox3.png", 0, 0); // Load the second splash screen onto the texture instead 
        									}
        									if (pLoop == 3) { //pLoop is the number of times this modifier has been loop.
        										texture.clearTextureAtlasSources(); // Clear the first splash screen from our texture
        										BitmapTextureAtlasTextureRegionFactory.createFromAsset(texture, GameSplashActivity.this, "AndEngineText.png", 0, 0); // Load the second splash screen onto the texture instead 
        									}
        									if (pLoop == 4) {
        										// You could do something here which would happen after the second loop. If you change the loop count this could become the third loop. 
        									}

        								}
        							});
        						}
        					},
        					new SequenceEntityModifier(
			                		new DelayModifier(1),
			                		new AlphaModifier(0.5f, 0, 1),
			                		new DelayModifier(2),
			                		new AlphaModifier(0.5f, 1, 0),
									new DelayModifier(0.5f)
        							
        					)
        			);

        		picture.registerEntityModifier(entityModifier); // We attach our modifier to our Picture sprite

                scene.attachChild(picture); // We attach our picture sprite to the active scene

                /* The code from the original GameSplashActivity to make it easier to compare
                picture.addShapeModifier(new SequenceModifier(
                		new IShapeModifierListener() {

							@Override
							public void onModifierFinished(IShapeModifier pShapeModifier, IShape pShape) {
								
								texture.clearTextureSources();
					            TextureRegionFactory.createFromAsset(texture, GameSplashActivity.this, "mercury.png", 0, 0);

								picture.addShapeModifier(new SequenceModifier(
				                		new IShapeModifierListener() {

											@Override
											public void onModifierFinished(
													IShapeModifier pShapeModifier,
													IShape pShape) {
												
												Intent menu = new Intent(GameSplashActivity.this, MenuActivity.class);
												startActivity(menu);
												finish();
											}
										},
				                		new DelayModifier(1),
				                		new AlphaModifier(0.5f, 0, 1),
				                		new DelayModifier(2),
				                		new AlphaModifier(0.5f, 1, 0),
										new DelayModifier(0.5f)
				                ));
							}
						},
						new DelayModifier(1),
                		new AlphaModifier(0.5f, 0, 1),
                		new DelayModifier(2),
                		new AlphaModifier(0.5f, 1, 0)
                ));
*/
                return scene;
        }
        
	    @Override
		public boolean onKeyDown(final int pKeyCode, final KeyEvent pEvent) { 
	    	// Maybe the user decides to use Android buttons instead? Lets try to stop the user from quitting with the back button, by accident.
	    	// And in this case, let him skip the splashscreen and go directly to the ScrollMenu.

			if (pKeyCode == KeyEvent.KEYCODE_BACK
					&& pEvent.getAction() == KeyEvent.ACTION_DOWN) { // Check if the back button is being pressed
				Intent menu = new Intent(GameSplashActivity.this, ScrollMenu.class); // Creates an intent in this activity, to prepare the next class
				startActivity(menu); // Runs the menu activity
				finish(); // Ends this activity to stop it from hogging precious Android memory.
				return true;
			}
			
			return super.onKeyDown(pKeyCode, pEvent);
		}
        
        @Override
        public void onLoadComplete() {}

}