package dk.dionysus.hjarl;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Typeface;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;

public class MenuActivity2 extends Activity {

	    @Override
	    public void onCreate(Bundle savedInstanceState) { 
	    	//The Bundle savedInstanceState makes sure that we can go out of the app, and come back to it with the same menu state. Like showing the highscore or the exit dialogue
	        super.onCreate(savedInstanceState); // Prepares the instance state
	        //setContentView(R.layout.main_new);
	        setContentView(R.layout.main); // The layout for our menu
	    
	        
	        // With no CSS running, we can make the menu look a bit fancier by setting a font:
	        Typeface font = Typeface.createFromAsset(getAssets(),"font/pf_tempesta_five.ttf");
	        
		    TextView btnHelp = (TextView) findViewById(R.id.btnHelp);
		    btnHelp.setTypeface(font);
		    
			btnHelp.setOnClickListener(new OnClickListener() {
				
				@Override
				public void onClick(View v) {
					Intent help = new Intent(MenuActivity2.this, HelpActivity.class);
					startActivity(help);
				}
			});
	        
		    TextView btnExit = (TextView) findViewById(R.id.btnExit); // Make the TextView with the ID: btnExit become an object in this script as well
	        btnExit.setTypeface(font); // Make this button use the font we prepared
	        btnExit.setOnClickListener(new OnClickListener() { // Here we make it possible to click the exit button
				
				@Override
				public void onClick(View v) {
					showExitDialog(); // The exit button was clicked? Then run the showExitdialog.
				}
			});
	        
	        TextView btnStartGame = (TextView) findViewById(R.id.btnStartGame); // setting up another button
	        btnStartGame.setTypeface(font); // add the fancy font
	        btnStartGame.setOnClickListener(new OnClickListener() { // make it clickable
				
				@Override
				public void onClick(View v) {
					Intent game = new Intent(MenuActivity2.this, OSControlSetup.class);
					//Intent game = new Intent(MenuActivity2.this, MovingBallExample.class); // When clicked, run MovingBallExample
					startActivity(game); // runs the game intent, which targets the MovingBallExample
				}
			});
	        
	        
	        TextView btnStartGame2 = (TextView) findViewById(R.id.btnStartGame2); // setting up another button
	        btnStartGame2.setTypeface(font); // add the fancy font
	        btnStartGame2.setOnClickListener(new OnClickListener() { // make it clickable
				
				@Override
				public void onClick(View v) {
					Intent game = new Intent(MenuActivity2.this, HjarlGameActivity.class); // When clicked, run RacerGameActivity
					startActivity(game); // runs the game intent, which targets the RacerGameActivity
				}
			});
	        
	        TextView btnStartGame3 = (TextView) findViewById(R.id.btnStartGame3); // setting up another button
	        btnStartGame3.setTypeface(font); // add the fancy font
	        btnStartGame3.setOnClickListener(new OnClickListener() { // make it clickable
				
				@Override
				public void onClick(View v) {
					Intent game = new Intent(MenuActivity2.this, RacerGameActivity.class); // When clicked, run RacerGameActivity
					startActivity(game); // runs the game intent, which targets the RacerGameActivity
				}
			});
	        
	        
	        TextView btnOptions = (TextView) findViewById(R.id.btnOptions);
	        btnOptions.setTypeface(font);
	        btnOptions.setOnClickListener(new OnClickListener() {
				
				@Override
				public void onClick(View v) {
					Intent game = new Intent(MenuActivity2.this, OptionsActivity.class);
					
					startActivity(game);
				}
			});
	        
	        TextView btnHighscore = (TextView) findViewById(R.id.btnHighscore);
	        btnHighscore.setTypeface(font);
	        btnHighscore.setOnClickListener(new OnClickListener() {
				
				@Override
				public void onClick(View v) {
					AlertDialog.Builder alertbox = new AlertDialog.Builder(MenuActivity2.this);
					alertbox.setTitle("HIGHSCORE");
					alertbox.setIcon(R.drawable.trophy);
					alertbox.setCancelable(false);
					
					Highscore score = new Highscore(MenuActivity2.this);
					StringBuilder str = new StringBuilder();
					
					for(int i=0;i<10;i++){
						if(i!=9)
							str.append(i+1 +"  .  "+score.getName(i)+"  ("+score.getScore(i)+" points)\n");
						else
							str.append(i+1 +".  "+score.getName(i)+"  ("+score.getScore(i)+" points)\n");
					}
					
		            alertbox.setMessage(str.toString());
					
		            alertbox.setPositiveButton("Close",
							new DialogInterface.OnClickListener() {
								public void onClick(DialogInterface dialog, int id) {
								}
							});
		            
		            alertbox.show();
		
				}
			});
	        
	    }

	    
	    @Override
		public boolean onKeyDown(final int pKeyCode, final KeyEvent pEvent) { 
	    	// Maybe the user decides to use Android buttons instead? Lets try to stop the user from quitting with the back button, by accident.

			if (pKeyCode == KeyEvent.KEYCODE_BACK
					&& pEvent.getAction() == KeyEvent.ACTION_DOWN) { // Check if the back button is being pressed
				showExitDialog(); // Run the showExitDialog.
				return true;
			}
			
			return super.onKeyDown(pKeyCode, pEvent);
		}
	    
	    public void showExitDialog() { // Here a showExitDialog is prepared. Its a kind of submenu, but since it is very simple its all done without XML
	    	AlertDialog.Builder builder = new AlertDialog.Builder(MenuActivity2.this); // Making an AlerDialog, its an Android feature
			builder.setMessage("Are you sure you want to exit?")
					.setCancelable(false)
					.setTitle("EXIT")
					.setPositiveButton("Yes",
							new DialogInterface.OnClickListener() {
								public void onClick(DialogInterface dialog, int id) {
									MenuActivity2.this.finish(); // if yes is clicked, close this class. If this class had been opened by another class, we would return to that class.
								}
							})
					.setNegativeButton("No", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							dialog.cancel(); // Of the NO choice is clicked, we cancel the AlertDialog and go back to Menuactivity2
						}
					});

			AlertDialog alert = builder.create(); // This takes the AlertDialog and prepares it
			alert.setIcon(R.drawable.icon); // Puts the application icon in the drawable folder into the dialog
			alert.show(); // shows the alert dialog
	    
	    }
	    
}