package dk.dionysus.hjarl;

import me.trifunovic.spaceassault.game.hud.HudScore;
import dk.dionysus.hjarl.Options;
import dk.dionysus.hjarl.R;
import org.anddev.andengine.engine.Engine;
import org.anddev.andengine.engine.camera.Camera;
import org.anddev.andengine.engine.handler.physics.PhysicsHandler;
import org.anddev.andengine.engine.options.EngineOptions;
import org.anddev.andengine.engine.options.EngineOptions.ScreenOrientation;
import org.anddev.andengine.engine.options.resolutionpolicy.RatioResolutionPolicy;
import org.anddev.andengine.entity.scene.Scene;
import org.anddev.andengine.entity.scene.background.ColorBackground;
import org.anddev.andengine.entity.sprite.AnimatedSprite;
import org.anddev.andengine.entity.util.FPSLogger;
import org.anddev.andengine.opengl.texture.TextureOptions;
import org.anddev.andengine.opengl.texture.atlas.bitmap.BitmapTextureAtlas;
import org.anddev.andengine.opengl.texture.atlas.bitmap.BitmapTextureAtlasTextureRegionFactory;
import org.anddev.andengine.opengl.texture.region.TiledTextureRegion;
import org.anddev.andengine.ui.activity.BaseGameActivity;


import android.app.AlertDialog;
import android.content.DialogInterface;
import android.view.KeyEvent;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.RelativeLayout.LayoutParams;

/**
 * (c) 2010 Nicolas Gramlich
 * (c) 2011 Zynga
 *
 * @author Nicolas Gramlich
 * @since 11:54:51 - 03.04.2010
 * 
 * @author Kasper Olesen
 * @since 18:29:20 - 19.12.2011
 * 
 */
public class MovingBallExample extends BaseGameActivity {
	// ===========================================================
	// Constants
	// ===========================================================

	private static final int CAMERA_WIDTH = 720;
	private static final int CAMERA_HEIGHT = 480;

	private static final float DEMO_VELOCITY = 100.0f;

	// ===========================================================
	// Fields
	// ===========================================================

	public static final HudScore score = new HudScore();
	
	private Camera mCamera;

	private BitmapTextureAtlas mBitmapTextureAtlas;
	private TiledTextureRegion mFaceTextureRegion;

    // SHARED PREFERENCES
    public static Options options; // We load the options class and aptly name it options
	
	// ===========================================================
	// Constructors
	// ===========================================================

	// ===========================================================
	// Getter & Setter
	// ===========================================================

	// ===========================================================
	// Methods for/from SuperClass/Interfaces
	// ===========================================================

	@Override
	public Engine onLoadEngine() {
		options = new Options(MovingBallExample.this); //load the options into the memory used for this activity.
		this.mCamera = new Camera(0, 0, CAMERA_WIDTH, CAMERA_HEIGHT);
		return new Engine(new EngineOptions(true, ScreenOrientation.LANDSCAPE, new RatioResolutionPolicy(CAMERA_WIDTH, CAMERA_HEIGHT), this.mCamera));
	}

	@Override
	public void onLoadResources() {
		this.mBitmapTextureAtlas = new BitmapTextureAtlas(128, 32, TextureOptions.BILINEAR_PREMULTIPLYALPHA);
		if (options.getSprite())
			this.mFaceTextureRegion = BitmapTextureAtlasTextureRegionFactory.createTiledFromAsset(this.mBitmapTextureAtlas, this, "gfx/face_circle_tiled.png", 0, 0, 2, 1);
		else
			this.mFaceTextureRegion = BitmapTextureAtlasTextureRegionFactory.createTiledFromAsset(this.mBitmapTextureAtlas, this, "gfx/face_box_tiled.png", 0, 0, 2, 1);
		this.mEngine.getTextureManager().loadTexture(this.mBitmapTextureAtlas);
	}

	@Override
	public Scene onLoadScene() {
		this.mEngine.registerUpdateHandler(new FPSLogger());

		final Scene scene = new Scene();
		score.reset();
		scene.setBackground(new ColorBackground(0.09804f, 0.6274f, 0.8784f));

		final int centerX = (CAMERA_WIDTH - this.mFaceTextureRegion.getWidth()) / 2;
		final int centerY = (CAMERA_HEIGHT - this.mFaceTextureRegion.getHeight()) / 2;
		final Ball ball = new Ball(centerX, centerY, this.mFaceTextureRegion);
		final PhysicsHandler physicsHandler = new PhysicsHandler(ball);
		ball.registerUpdateHandler(physicsHandler);
		physicsHandler.setVelocity(DEMO_VELOCITY, DEMO_VELOCITY);
		scene.attachChild(ball);

		return scene;
	}

	@Override
	public void onLoadComplete() {

	}

	// ===========================================================
	// Methods
	// ===========================================================

	// ===========================================================
	// Inner and Anonymous Classes
	// ===========================================================

	private static class Ball extends AnimatedSprite {
		private final PhysicsHandler mPhysicsHandler;

		public Ball(final float pX, final float pY, final TiledTextureRegion pTextureRegion) {
			super(pX, pY, pTextureRegion);
			this.mPhysicsHandler = new PhysicsHandler(this);
			this.registerUpdateHandler(this.mPhysicsHandler);
		}

		@Override
		protected void onManagedUpdate(final float pSecondsElapsed) {
			if(this.mX < 0) {
				this.mPhysicsHandler.setVelocityX(DEMO_VELOCITY);
				score.addPoints();
			} else if(this.mX + this.getWidth() > CAMERA_WIDTH) {
				this.mPhysicsHandler.setVelocityX(-DEMO_VELOCITY * 2);
				score.addPoints();
			}

			if(this.mY < 0) {
				this.mPhysicsHandler.setVelocityY(DEMO_VELOCITY);
				score.addPoints();
			} else if(this.mY + this.getHeight() > CAMERA_HEIGHT) {
				this.mPhysicsHandler.setVelocityY(-DEMO_VELOCITY * 2);
				score.addPoints();
			}
 
			super.onManagedUpdate(pSecondsElapsed);
		}
	}
	
    @Override
	public boolean onKeyDown(final int pKeyCode, final KeyEvent pEvent) { 
    	// Maybe the user decides to use Android buttons instead? Lets try to stop the user from quitting with the back button, by accident.

		if (pKeyCode == KeyEvent.KEYCODE_BACK
				&& pEvent.getAction() == KeyEvent.ACTION_DOWN) { // Check if the back button is being pressed
			showExitDialog(); // Run the showExitDialog.
			return true;
		}
		
		return super.onKeyDown(pKeyCode, pEvent);
	}
    
    public void showExitDialog() { // Here a showExitDialog is prepared. Its a kind of submenu, but since it is very simple its all done without XML
    	AlertDialog.Builder builder = new AlertDialog.Builder(MovingBallExample.this); // Making an AlerDialog, its an Android feature
		builder.setMessage("Are you sure you want to exit?")
				.setCancelable(false)
				.setTitle("EXIT")
				.setPositiveButton("Yes",
						new DialogInterface.OnClickListener() {
							public void onClick(DialogInterface dialog, int id) {
								final Highscore highscore = new Highscore(getApplicationContext());
								
								if(highscore.inHighscore(score.getScore()))
								{
								runOnUiThread(new Runnable() {
									
									@Override
									public void run() {
										AlertDialog.Builder alert = new AlertDialog.Builder(MovingBallExample.this);

										alert.setTitle("HIGHSCORE");
										alert.setIcon(R.drawable.trophy);
										alert.setMessage("Score : "+score.getScore()+"\nEnter your name:");

										final LinearLayout layout = new LinearLayout(MovingBallExample.this);
										final EditText input = new EditText(MovingBallExample.this);
										layout.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT,LayoutParams.FILL_PARENT));
										input.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT,LayoutParams.FILL_PARENT));
										layout.setPadding(20, 0, 20, 0);
										layout.addView(input);
										
										alert.setView(layout);

										alert.setPositiveButton("Ok", new DialogInterface.OnClickListener() {
										public void onClick(DialogInterface dialog, int whichButton) {
										  String value = input.getText().toString();
										  
											highscore.addScore(value,score.getScore());
										  finish();
										  }
										});

										alert.setNegativeButton("Cancel", new DialogInterface.OnClickListener() {
										  public void onClick(DialogInterface dialog, int whichButton) {
											  finish();
										  }
										});

										alert.show();
									}
								});
								}else{
									finish();
								}
								//MovingBallExample.this.finish(); // if yes is clicked, close this class. If this class had been opened by another class, we would return to that class.
							}
						})
				.setNegativeButton("No", new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface dialog, int id) {
						dialog.cancel(); // Of the NO choice is clicked, we cancel the AlertDialog and go back to Menuactivity2
					}
				});

		AlertDialog alert = builder.create(); // This takes the AlertDialog and prepares it
		alert.setIcon(R.drawable.icon); // Puts the application icon in the drawable folder into the dialog
		alert.show(); // shows the alert dialog
    
    }
}
